@@ -1,25 +1,26 @@
 /* Miscellaneous Emacs functions reimplementation
+
+   Copyright (c) 2008 Free Software Foundation, Inc.
    Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Sandro Sigala.
    Copyright (c) 2003, 2004, 2005, 2006, 2007 Reuben Thomas.
    Copyright (c) 2004 David A. Capello.
-   All rights reserved.
 
-   This file is part of Zile.
+   This file is part of GNU Zile.
 
-   Zile is free software; you can redistribute it and/or modify it under
-   the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 3, or (at your option) any later
-   version.
+   GNU Zile is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-   Zile is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-   for more details.
+   GNU Zile is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Zile; see the file COPYING.  If not, write to the Free
-   Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
-   02111-1301, USA.  */
+   along with GNU Zile; see the file COPYING.  If not, write to the
+   Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
+   MA 02111-1301, USA.  */
 
 #include "config.h"
 
@@ -30,6 +31,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <unistd.h>
 
 #include "zile.h"
@@ -440,8 +442,8 @@ universal_argument (int keytype, int xarg)
 	  else if (i != 0)
 	    {
 	      /* If i == 0 do nothing (the Emacs behavior is a little
-	         strange in this case, it waits for one more key that is
-	         eaten, and then goes back to the normal state). */
+		 strange in this case, it waits for one more key that is
+		 eaten, and then goes back to the normal state). */
 	      ungetkey (key);
 	      break;
 	    }
@@ -1599,10 +1601,12 @@ it as the contents of the region.
 {
   FILE *pipe;
   astr out, s;
-  int lines = 0;
+  int lines = 0, fd;
+  ssize_t written;
   astr cmd;
   char tempfile[] = P_tmpdir "/zileXXXXXX";
-  char *ms = minibuf_read ("Shell command: ", "");
+  char *ms = minibuf_read ("Shell command: ", ""), *p;
+  Region r;
 
   if (ms == NULL)
     return cancel ();
@@ -1614,28 +1618,30 @@ it as the contents of the region.
 
   cmd = astr_new ();
 
-  {
-    Region r;
-    char *p;
-    int fd;
+  fd = mkstemp (tempfile);
+  if (fd == -1)
+    {
+      minibuf_error ("Cannot open temporary file");
+      return FALSE;
+    }
 
-    fd = mkstemp (tempfile);
-    if (fd == -1)
-      {
-	minibuf_error ("Cannot open temporary file");
-	return FALSE;
-      }
+  calculate_the_region (&r);
+  p = copy_text_block (r.start.n, r.start.o, r.size);
+  written = write (fd, p, r.size);
+  free (p);
+  close (fd);
 
-    calculate_the_region (&r);
-    p = copy_text_block (r.start.n, r.start.o, r.size);
-    write (fd, p, r.size);
-    free (p);
-
-    close (fd);
-
-    astr_afmt (cmd, "%s 2>&1 <%s", ms, tempfile);
-  }
+  if (written != (ssize_t) r.size)
+    {
+      if (written == -1)
+        minibuf_error ("Error writing to temporary file: %s",
+                       strerror (errno));
+      else
+        minibuf_error ("Error writing to temporary file");
+      return FALSE;
+    }
 
+  astr_afmt (cmd, "%s 2>&1 <%s", ms, tempfile);
   pipe = popen (astr_cstr (cmd), "r");
   if (pipe == NULL)
     {
