@@ -1,25 +1,26 @@
 /* Line-oriented editing functions
+
+   Copyright (c) 2008 Free Software Foundation, Inc.
    Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 Sandro Sigala.
    Copyright (c) 2003, 2004, 2005, 2006, 2007, 2008 Reuben Thomas.
    Copyright (c) 2004 David A. Capello.
-   All rights reserved.
 
-   This file is part of Zile.
+   This file is part of GNU Zile.
 
-   Zile is free software; you can redistribute it and/or modify it under
-   the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 3, or (at your option) any later
-   version.
+   GNU Zile is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-   Zile is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-   for more details.
+   GNU Zile is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Zile; see the file COPYING.  If not, write to the Free
-   Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
-   02111-1301, USA.  */
+   along with GNU Zile; see the file COPYING.  If not, write to the
+   Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
+   MA 02111-1301, USA.  */
 
 #include "config.h"
 
@@ -87,9 +88,9 @@ insert_char (int c)
   if (cur_bp->flags & BFLAG_OVERWRITE)
     {
       /* Current character isn't the end of line
-         && isn't a \t
-         || tab width isn't correct
-         || current char is a \t && we are in the tab limit.  */
+	 && isn't a \t
+	 || tab width isn't correct
+	 || current char is a \t && we are in the tab limit.  */
       if ((cur_bp->pt.o < astr_len (cur_bp->pt.p->item))
 	  &&
 	  ((*astr_char (cur_bp->pt.p->item, (ptrdiff_t) cur_bp->pt.o) != '\t')
@@ -699,7 +700,7 @@ does nothing.
   if (target_goalc > 0)
     {
       /* If not at EOL on target line, insert spaces & tabs up to
-         target_goalc; if already at EOL on target line, insert a tab.
+	 target_goalc; if already at EOL on target line, insert a tab.
        */
       cur_goalc = get_goalc ();
       if (cur_goalc < target_goalc)
