@@ -1,24 +1,25 @@
 /* Lisp variables
+
+   Copyright (c) 2008 Free Software Foundation, Inc.
    Copyright (c) 2001 Scott "Jerry" Lawrence.
    Copyright (c) 2005 Reuben Thomas.
-   All rights reserved.
 
-   This file is part of Zile.
+   This file is part of GNU Zile.
 
-   Zile is free software; you can redistribute it and/or modify it under
-   the terms of the GNU General Public License as published by the Free
-   Software Foundation; either version 3, or (at your option) any later
-   version.
+   GNU Zile is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-   Zile is distributed in the hope that it will be useful, but WITHOUT ANY
-   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-   for more details.
+   GNU Zile is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Zile; see the file COPYING.  If not, write to the Free
-   Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
-   02111-1301, USA.  */
+   along with GNU Zile; see the file COPYING.  If not, write to the
+   Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
+   MA 02111-1301, USA.  */
 
 #ifndef LISTS_H
 #define LISTS_H
@@ -56,7 +57,6 @@ void leTagReplace (le * list, int tagval, le * newinfo);
 
 astr leDump (le * list, int indent);
 astr leDumpEval (le * list, int indent);
-astr leDumpEvalTree (le * list, int indent);
 astr leDumpReformat (le * tree);
 
 #endif
